<?php

namespace Controller;

use Util\Utilities;
use Util\Instance\ServiceInstance;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;

class License
{
    /**
     * @param Request\Filter $request
     * @param Response $response
     */
    public function getProductLicense(Request\Filter $request, Response $response) {
        try {
            $conditions           = $request->getFilterCriteria()->getConditions();
            $organizationId       = Utilities::getValueInFilterDataSourceByName($conditions, 'ORGANIZATION_ID');
            $productId            = Utilities::getValueInFilterDataSourceByName($conditions, 'PRODUCT_ID');
            $elementIds           = Utilities::getValueInFilterDataSourceByName($conditions, 'ELEMENT_IDS');
            $serverId             = Utilities::getValueInFilterDataSourceByName($conditions, 'SERVER_ID');
            $user                 = Utilities::getValueInFilterDataSourceByName($conditions, 'USER');
            $password             = Utilities::getValueInFilterDataSourceByName($conditions, 'PASSWORD');
            $hasUserData          = Utilities::getValueInFilterDataSourceByName($conditions, 'HAS_USER_DATA');
            $returnOrgAndBranches = Utilities::getValueInFilterDataSourceByName($conditions, 'RETURN_ORG_AND_BRANCHES');
            $userData             = ServiceInstance::getLicense()->getProductLicense($organizationId, $productId, $elementIds, 
                $serverId, $user, $password, $hasUserData, $returnOrgAndBranches);
            $response->addDataSet(new DataSet ('userData', $userData));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }


    public function validateUserSupportOperator(Request\Filter $request, Response $response) {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            $cdoperador = Utilities::getValueInFilterDataSourceByName($conditions, 'CDOPERADOR');
            $password   = Utilities::getValueInFilterDataSourceByName($conditions, 'PASSWORD');
            $isSupportOperator   = ServiceInstance::getSupportOperator()->validateUser($cdoperador, $password);
            $response->addDataSet(new DataSet ('validateUserSupportOperator', $isSupportOperator));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    /**
     * @param Request\Filter $request
     * @param Response $response
     */
    public function logout(Request\Filter $request, Response $response){
        try {
            $conditions   = $request->getFilterCriteria()->getConditions();
            $token        = Utilities::getValueInFilterDataSourceByName($conditions, 'TOKEN');
            ServiceInstance::getLicense()->logout($token);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    /**
     * @param Request\DataSet $request
     * @param Response $response
     */
    public function saveVariableMeasure(Request\DataSet $request, Response $response){
        try {
            $rows = $request->getDataSet()->getRows();
            if (isset($rows[1]) && !Utilities::isAssociativeArray((array)$rows[1])) {
                $variableMeasure   = $rows[0];
                $generalCollection = $rows[1];
                $resultVariableMeasure   = ServiceInstance::getLicense()->saveVariableMeasure($variableMeasure);
                $resultGeneralCollection = ServiceInstance::getLicense()->saveGeneralCollection($generalCollection);
                $response->addDataSet(new DataSet ('generalCollectionResult', array($resultGeneralCollection)));
            } else {
                $resultVariableMeasure = ServiceInstance::getLicense()->saveVariableMeasure($rows);
            }
            $response->addDataSet(new DataSet ('variableMeasureResult', array($resultVariableMeasure)));
        } catch(\Exception $ex){
            $response->addDataSet(new DataSet ('variableMeasureResult', array($ex->getMessage())));
        }
    }

    /**
     * @param Request $request
     * @param Response $response
     */
    public function testConnection(Request $request, Response $response) {
        try {
            ServiceInstance::getLicense()->testConnection();
            $response->addDataSet(new DataSet ('testConnection', array(true)));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    /**
     * @param Request\DataSet $request
     * @param Response $response
     */
    public function saveOrgFilial(Request\DataSet $request, Response $response) {
        try {
            $row      = $request->getDataSet()->getRows()[0];
            $orgId    = $row['NRORG'];
            $cdFilial = $row['CDFILIAL'];
            ServiceInstance::getLicense()->saveOrgFilial($orgId, $cdFilial);
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
}